@@ -1,9 +1,14 @@
 #ifndef _fastGHQuad_LIB_H
 #define _fastGHQuad_LIB_H
 
+#define USE_FC_LEN_T
 #include <Rcpp.h>
 #include <R_ext/Lapack.h>
 
+#ifndef FCONE
+# define FCONE
+#endif
+
 /*
  * note : RcppExport is an alias to `extern "C"` defined by Rcpp.
  *
